Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(757)

Unified Diff: third_party/WebKit/Source/modules/webaudio/BaseAudioContext.h

Issue 2103043007: Rename AbstractAudioContext to BaseAudioContext (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Use ASSERT(isGraphOwner()) instead of DCHECK Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/webaudio/BaseAudioContext.h
diff --git a/third_party/WebKit/Source/modules/webaudio/AbstractAudioContext.h b/third_party/WebKit/Source/modules/webaudio/BaseAudioContext.h
similarity index 95%
rename from third_party/WebKit/Source/modules/webaudio/AbstractAudioContext.h
rename to third_party/WebKit/Source/modules/webaudio/BaseAudioContext.h
index 942b7ff67613c808866669403c498570b0da65a9..585dec1f71edfef74b2d750455901d5eb155803e 100644
--- a/third_party/WebKit/Source/modules/webaudio/AbstractAudioContext.h
+++ b/third_party/WebKit/Source/modules/webaudio/BaseAudioContext.h
@@ -22,8 +22,8 @@
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef AbstractAudioContext_h
-#define AbstractAudioContext_h
+#ifndef BaseAudioContext_h
+#define BaseAudioContext_h
#include "bindings/core/v8/ActiveScriptWrappable.h"
#include "bindings/core/v8/ScriptPromise.h"
@@ -79,11 +79,11 @@ class SecurityOrigin;
class StereoPannerNode;
class WaveShaperNode;
// AbstractAudioContext is the cornerstone of the web audio API and all AudioNodes are created from it.
// For thread safety between the audio thread and the main thread, it has a rendering graph locking mechanism.
-class MODULES_EXPORT AbstractAudioContext : public EventTargetWithInlineData, public ActiveScriptWrappable, public ActiveDOMObject {
- USING_GARBAGE_COLLECTED_MIXIN(AbstractAudioContext);
+class MODULES_EXPORT BaseAudioContext : public EventTargetWithInlineData, public ActiveScriptWrappable, public ActiveDOMObject {
+ USING_GARBAGE_COLLECTED_MIXIN(BaseAudioContext);
DEFINE_WRAPPERTYPEINFO();
public:
// The state of an audio context. On creation, the state is Suspended. The state is Running if
@@ -97,9 +97,9 @@ public:
};
// Create an AudioContext for rendering to the audio hardware.
- static AbstractAudioContext* create(Document&, ExceptionState&);
+ static BaseAudioContext* create(Document&, ExceptionState&);
- ~AbstractAudioContext() override;
+ ~BaseAudioContext() override;
DECLARE_VIRTUAL_TRACE();
@@ -216,7 +216,7 @@ public:
// Keeps track of the number of connections made.
void incrementConnectionCount()
{
- ASSERT(isMainThread());
+ DCHECK(isMainThread());
m_connectionCount++;
}
@@ -268,8 +268,8 @@ public:
void recordUserGestureState();
protected:
- explicit AbstractAudioContext(Document*);
- AbstractAudioContext(Document*, unsigned numberOfChannels, size_t numberOfFrames, float sampleRate);
+ explicit BaseAudioContext(Document*);
+ BaseAudioContext(Document*, unsigned numberOfChannels, size_t numberOfFrames, float sampleRate);
void initialize();
void uninitialize();
@@ -350,7 +350,7 @@ private:
// Graph locking.
RefPtr<DeferredTaskHandler> m_deferredTaskHandler;
// The state of the AbstractAudioContext.
AudioContextState m_contextState;
AsyncAudioDecoder m_audioDecoder;
@@ -379,4 +379,4 @@ private:
} // namespace blink
-#endif // AbstractAudioContext_h
+#endif // BaseAudioContext_h

Powered by Google App Engine
This is Rietveld 408576698
@@ -79,11 +79,11 @@ class SecurityOrigin;
class StereoPannerNode;
class WaveShaperNode;
-// AbstractAudioContext is the cornerstone of the web audio API and all AudioNodes are created from it.
+// BaseAudioContext is the cornerstone of the web audio API and all AudioNodes are created from it.
// For thread safety between the audio thread and the main thread, it has a rendering graph locking mechanism.
@@ -350,7 +350,7 @@ private:
// Graph locking.
RefPtr<DeferredTaskHandler> m_deferredTaskHandler;
- // The state of the AbstractAudioContext.
+ // The state of the BaseAudioContext.
AudioContextState m_contextState;
AsyncAudioDecoder m_audioDecoder;